@@ -270,8 +270,9 @@ def random_numbers(start, end, size):
     return np.random.randint(start, end, size)
 
 
-def five_column_dataset(num_rows):
-    size = num_rows
+@pytest.fixture(scope="session")
+def five_column_dataset():
+    size = 100
     df = pd.DataFrame(columns=['First', 'Last', 'Gender', 'Birthdate'])
     df['First'] = random_names('first_names', size)
     df['Last'] = random_names('last_names', size)
